---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Fortran code**
Minimal Fortran needed to reproduce this bug

**Python code**
Minimal Python needed to reproduce this bug

**Software (please complete the following information):**
 - OS: [e.g. Linux]
 - gfort2py version:
 - gfortran version:
 - gfortran compile options:
 - Python version:
 - If this involves arrays numpy version:

**Additional context**
Add any other context about the problem here.
